@@ -1,21 +1,23 @@
 # -*- coding: utf-8 -*-
-##################################################
-#
-# semantyk 
-# Package | Semantyk
-#
-# Author: Daniel Bakas Amuchastegui
-# August 31, 2017
-# 
-# Copyright © Semantyk 2020. All rights reserved.
-##################################################
+"""
+–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
+# Semantyk 
+Package | `__init__.py`
+
+Daniel Bakas Amuchastegui\
+August 31, 2017
+
+Copyright © Semantyk 2020. All rights reserved.\
+–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
+"""
 
 __author__ = 'Daniel Bakas Amuchastegui'
 __email__ = 'danielbakas@gmail.com'
-__version__ = '0.0.0.48'
+__version__ = '0.0.0.50'
 
 from . import archive
 from . import av_reality
+from . import core
 from . import das
 from . import dots
 from . import dvm
@@ -28,6 +30,7 @@ from . import uuid_generator
 
 from .archive import *
 from .av_reality import *
+from .core import *
 from .dots import *
 from .dvm import *
 from .games import *
